import { IoMessageCode, IoMessageLevel } from '../io-message';
/**
 * Information for each IO Message Code.
 */
export interface CodeInfo {
    /**
     * The message code.
     */
    code: IoMessageCode;
    /**
     * A brief description of the meaning of this IO Message.
     */
    description: string;
    /**
     * The message level
     */
    level: IoMessageLevel;
    /**
     * The name of the payload interface, if applicable.
     * Some Io Messages include a payload, with a specific interface. The name of
     * the interface is specified here so that it can be linked with the message
     * when documentation is generated.
     *
     * The interface _must_ be exposed directly from toolkit-lib, so that it will
     * have a documentation page generated (that can be linked to).
     */
    interface?: string;
}
/**
 * We have a rough system by which we assign message codes:
 * - First digit groups messages by action, e.g. synth or deploy
 * - X000-X009 are reserved for timings
 * - X900-X999 are reserved for results
 */
export declare const CODES: {
    CDK_TOOLKIT_I1000: CodeInfo;
    CDK_TOOLKIT_I1901: CodeInfo;
    CDK_TOOLKIT_I1902: CodeInfo;
    CDK_TOOLKIT_I2901: CodeInfo;
    CDK_TOOLKIT_E3900: CodeInfo;
    CDK_TOOLKIT_I5000: CodeInfo;
    CDK_TOOLKIT_I5001: CodeInfo;
    CDK_TOOLKIT_I5002: CodeInfo;
    CDK_TOOLKIT_I5031: CodeInfo;
    CDK_TOOLKIT_I5050: CodeInfo;
    CDK_TOOLKIT_I5060: CodeInfo;
    CDK_TOOLKIT_I5900: CodeInfo;
    CDK_TOOLKIT_E5001: CodeInfo;
    CDK_TOOLKIT_I6000: CodeInfo;
    CDK_TOOLKIT_E6001: CodeInfo;
    CDK_TOOLKIT_E6900: CodeInfo;
    CDK_TOOLKIT_I7000: CodeInfo;
    CDK_TOOLKIT_I7010: CodeInfo;
    CDK_TOOLKIT_E7010: CodeInfo;
    CDK_TOOLKIT_E7900: CodeInfo;
    CDK_ASSEMBLY_I0042: CodeInfo;
    CDK_ASSEMBLY_I0241: CodeInfo;
    CDK_ASSEMBLY_I1000: CodeInfo;
    CDK_ASSEMBLY_I1001: CodeInfo;
    CDK_ASSEMBLY_E1002: CodeInfo;
    CDK_ASSEMBLY_I1003: CodeInfo;
    CDK_ASSEMBLY_E1111: CodeInfo;
};
