import type { Logger } from '@smithy/types';
import type { IoMessage, IoRequest } from '../io-message';
import type { ActionAwareIoHost, IoMessageCodeCategory } from './types';
import type { ToolkitAction } from '../../../toolkit';
import type { IIoHost } from '../io-host';
/**
 * An IoHost wrapper that adds the given action to an actionless message before
 * sending the message to the given IoHost
 */
export declare function withAction(ioHost: IIoHost, action: ToolkitAction): {
    notify: <T>(msg: Omit<IoMessage<T>, "action">) => Promise<void>;
    requestResponse: <T, U>(msg: Omit<IoRequest<T, U>, "action">) => Promise<U>;
};
/**
 * An IoHost wrapper that strips out ANSI colors and styles from the message before
 * sending the message to the given IoHost
 */
export declare function withoutColor(ioHost: IIoHost): IIoHost;
/**
 * An IoHost wrapper that strips out emojis from the message before
 * sending the message to the given IoHost
 */
export declare function withoutEmojis(ioHost: IIoHost): IIoHost;
/**
 * An IoHost wrapper that trims whitespace at the beginning and end of messages.
 * This is required, since after removing emojis and ANSI colors,
 * we might end up with floating whitespace at either end.
 */
export declare function withTrimmedWhitespace(ioHost: IIoHost): IIoHost;
export declare function asSdkLogger(ioHost: IIoHost, action: ToolkitAction): Logger;
/**
 * Turn an ActionAwareIoHost into a logger that is compatible with older code, but doesn't support data
 */
export declare function asLogger(ioHost: ActionAwareIoHost, category?: IoMessageCodeCategory): {
    trace: (msg: string, ...args: any[]) => Promise<void>;
    debug: (msg: string, ...args: any[]) => Promise<void>;
    info: (msg: string, ...args: any[]) => Promise<void>;
    warn: (msg: string, ...args: any[]) => Promise<void>;
    error: (msg: string, ...args: any[]) => Promise<void>;
};
